@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
-our $DATE = '2020-02-07'; # DATE
-our $VERSION = '0.100'; # VERSION
+our $DATE = '2021-02-21'; # DATE
+our $VERSION = '0.101'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,11 +27,11 @@ sub munge_files {
 
 sub munge_file {
     my ($self, $file) = @_;
-    my $content = $file->content;
+    my $content_as_bytes = $file->encoded_content;
     my $directive = $self->_directive_re;
-    if ($content =~ s{^#\s*$directive:\s*(.*?)\s+(\w+)(?:\s+(\w+))?\s*$}
-                     {$self->_insert_block($1, $2, $3, $file->name)}egm) {
-        $file->content($content);
+    if ($content_as_bytes =~ s{^#\s*$directive:\s*(.*?)\s+(\w+)(?:\s+(\w+))?\s*$}
+                              {$self->_insert_block($1, $2, $3, $file->name)}egm) {
+        $file->encoded_content($content_as_bytes);
     }
 }
 
@@ -82,7 +82,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.100 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2020-02-07.
+This document describes version 0.101 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-02-21.
 
 =head1 SYNOPSIS
 
@@ -184,7 +184,7 @@ Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-In
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-InsertBlock>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-InsertBlock/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -209,7 +209,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
